==> graphhopper-core-2.2-sources.jar: com/graphhopper/routing/ev/MaxWeight.java <==
/*
 *  Licensed to GraphHopper GmbH under one or more contributor
 *  license agreements. See the NOTICE file distributed with this work for
 *  additional information regarding copyright ownership.
 *
 *  GraphHopper GmbH licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except in
 *  compliance with the License. You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.graphhopper.routing.ev;

/**
 * One of the four logistic attributes that can be stored per edge.
 *
 * @see MaxHeight
 * @see MaxLength
 * @see MaxWidth
 */
public class MaxWeight {
    public static final String KEY = "max_weight";

    /**
     * Currently enables to store 0.1 to max=0.1*2⁸ tons and infinity. If a value is between the maximum and infinity
     * it is assumed to use the maximum value. To save bits it might make more sense to store only a few values like
     * it was done with the MappedDecimalEncodedValue still handling (or rounding) of unknown values is unclear.
     */
    public static DecimalEncodedValue create() {
        return new UnsignedDecimalEncodedValue(KEY, 8, 0.1, Double.POSITIVE_INFINITY, false);
    }
}

==> graphhopper-core-9.1-sources.jar: com/graphhopper/routing/ev/MaxWeight.java <==
/*
 *  Licensed to GraphHopper GmbH under one or more contributor
 *  license agreements. See the NOTICE file distributed with this work for
 *  additional information regarding copyright ownership.
 *
 *  GraphHopper GmbH licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except in
 *  compliance with the License. You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.graphhopper.routing.ev;

/**
 * One of the four logistic attributes that can be stored per edge.
 *
 * @see MaxHeight
 * @see MaxLength
 * @see MaxWidth
 */
public class MaxWeight {
    public static final String KEY = "max_weight";

    /**
     * Currently enables to store 0.1 to max=0.1*2⁸ tons and infinity. If a value is between the maximum and infinity
     * it is assumed to use the maximum value. To save bits it might make more sense to store only a few values like
     * it was done with the MappedDecimalEncodedValue still handling (or rounding) of unknown values is unclear.
     */
    public static DecimalEncodedValue create() {
        return new DecimalEncodedValueImpl(KEY, 8, 0, 0.1, false, false, true);
    }
}
